@@ -6,7 +6,7 @@ use futures::{stream, StreamExt};
 
 use crate::client::event::{
     DeleteFriendEvent, FriendMessageRecallEvent, FriendPokeEvent, GroupAudioMessageEvent,
-    GroupLeaveEvent, GroupMessageEvent, GroupMessageRecallEvent, GroupMuteEvent,
+    GroupDisbandEvent, GroupLeaveEvent, GroupMessageEvent, GroupMessageRecallEvent, GroupMuteEvent,
     GroupNameUpdateEvent, MemberPermissionChangeEvent, NewFriendEvent, NewMemberEvent,
 };
 use crate::client::handler::QEvent;
@@ -419,6 +419,14 @@ impl Client {
                     ))
                     .await;
             }
+            PushTransInfo::GroupDisband(disband) => {
+                self.handler
+                    .handle(QEvent::GroupDisband(GroupDisbandEvent {
+                        client: self.clone(),
+                        disband,
+                    }))
+                    .await;
+            }
         }
     }
 
